/*
	* Protection Racket - Defend/Attack four limos at your designated base, two rounds, quicker team wins *
	* Get Stretch - Capture the flag but with limos - you must have your limo at your base to score *
	* Editors (Add to list as you edit)
		* Force
*/

const SCRIPT_PATH = "Scripts/LUMinimodes/";
const PROTECTION = 0;
const STRETCH = 1;

enum script {
	mode = "LU Protection Racket"
	version = 0.1
	author = "Force"
}

/* Team controlling stuff */
Attack_Count <- 0; /* Team count for the attacking side */
Defend_Count <- 0; /* Team count for the defending side */
Attack_Score <- 0; /* Team score for the attacking side */
Defend_Score <- 0; /* Team score for the defending side */

/* Server settings */
Server_Mode <- PROTECTION; /* Whether it's 0 (Protection Racket) or 1 (Get Stretch) - Modes get switched when a team reaches 25 wins (or can be done manually) */
Info <- array( GetMaxPlayers() ); /* The array for storing player info */
Mode_Loaded <- false;

/* Message colours */
Blue <- Colour( 0, 0, 255 );
LBlue <- Colour( 51, 51, 153 );
Red <- Colour( 255, 0, 0 );
Green <- Colour( 0, 255, 0 );
Orange <- Colour( 255, 153, 0 );
Yellow <- Colour( 255, 255, 0 );

/* Protection Racket settings */
Target_Time <- 0; /* How long the other team has to win the match (in ticks) */
Limo_Count <- 4; /* How many limos are still surviving */
Protection_Round <- 1; /* Default to the first round for the protection game mode */

/* Spawn points */
Attack_Spawn <- Vector( 340.40, -165.47, 10.80 ); /* The spawn point for the attacking side */
Defend_Spawn <- Vector( 198.37, -42.12, 15.80 ); /* The spawn point for the defending side */
LimoSpawns <- array( 4 ); /* The array to hold info on where the limos will spawn */
LimoSpawns = [ Vector( 147.50, -40.40, 16.06 ), Vector( 189.37, -41.30, 16.06 ), Vector( 191.80, -6.85, 16.06 ), Vector( 166.94, -26.45, 15.89 ) ];
LimoAngles <- array( 4 );
LimoAngles = [ 270.00, 0.00, 178.00, 271.00 ];

function onScriptLoad()
{
	local msg = format( "%s v%.1f by %s", script.mode, script.version, script.author );
	
	dofile( SCRIPT_PATH + "Utils.nut" );
	Loadscripts();
	
	print( "[Loaded] " + msg );
}

function onScriptUnload()
{
	print( " * LU minimodes unloaded! *" );
}

function onPlayerJoin( pPlayer )
{
	Message( "*** " + pPlayer + " has entered the game!" );
	Info[ pPlayer.ID ] = PlayerInfo();
	
	if ( !Mode_Loaded ) SetScriptData( "ModeLoaded", 0 );
	
	if ( ( GetPlayers() == 2 ) && ( !Mode_Loaded ) ) StartProtection();
}

function onPlayerSpawn( pPlayer, iClass )
{
	/* Once the player spawns we need to assign them to a team */
	if ( Info[ pPlayer.ID ].Team == -1 ) AssignTeam( pPlayer );
	else RespawnPlayer( pPlayer );
	
	pPlayer.SetWeapon( 4, 999 );
	pPlayer.SetWeapon( 5, 999 );
	
	CallClientFunc( pPlayer, "Main-C.nut", "UpdateHUD" );
	CallClientFunc( pPlayer, "Main-C.nut", "ScoreUpdate" );
}

function onPlayerKill( pKiller, pKilled, iWeapon, iBodyPart )
{
	local szWeapon = GetWeaponName( iWeapon ), szBodyPart = GetBodyPartName( iBodyPart );
	
	if ( szBodyPart == "Unknown" ) szBodyPart = "Body";
	Message( "** " + pKiller + " has killed " + pKilled + " (" + szWeapon + ") (" + szBodyPart + ")", Red );
	
	if ( GetScriptData( "RoundStarted" ) )
	{
		pKiller.Score += 2;
		pKilled.Score --;
	}
}

function onPlayerDeath( pPlayer, iReason )
{
	Message( "** " + pPlayer + " has died.", Red );
	
	if ( GetScriptData( "RoundStarted" ) ) pPlayer.Score --;
}

function onPlayerCommand( pPlayer, szCmd, szParams )
{
	if ( ( szCmd == "info" ) || ( szCmd == "script" ) )
	{
		local msg = format( "** Script ** %s v%.1f by %s", script.mode, script.version, script.author );
		Message( msg, LBlue );
	}
}

function onPlayerPart( pPlayer, iReason )
{
	local szReason = GetReasonID( iReason );
	Message( "*** " + pPlayer + " has left the game! [" + szReason + "]" );
	
	if ( Info[ pPlayer.ID ].Team == 0 ) Attack_Count --;
	else Defend_Count --;
	
	Info[ pPlayer.ID ] = null;
	
	if ( ( GetPlayers() - 1 ) == 0 )
	{
		/* Send the data off so the client can read it */
		SetScriptData( "Limo_Count", 4 );
		SetScriptData( "Protection_Round", 1 );
		SetScriptData( "RoundStarted", 0 );
		
		Limo_Count <- 4;
		Protection_Round <- 1;
		Mode_Loaded <- false;
	}
}