/*
	* All the functions to do with the Protection Racket game mode *
*/

function StartProtection()
{	
	/* Send the objectives of the game mode */
	Message( "*** Protection Racket gamemode loaded ***", Red );
	Message( "There will be two rounds where you take it in turns to attack or defend the hospital.", Orange );
	Message( "The team that destroys the limos the quickest wins!", Orange );
	Message( "The round will start in 20 seconds...", Yellow );
	
	NewTimer( "RestartProtection", 5000, 1 );
	
	/* Reset the settings */
	Attack_Score <- 0;
	Defend_Score <- 0;
	Limo_Count <- 4;
	Attack_Spawn <- Vector( 340.40, -165.47, 10.80 );
	Defend_Spawn <- Vector( 198.37, -42.12, 15.80 );
	Protection_Round <- 1;
	Countdown <- 5;
	
	/* Load the spawn points and the four limos */
	//ChooseBases();
	
	/* Send the data off so the client can read it */
	SetScriptData( "Attack_Score", Attack_Score );
	SetScriptData( "Defend_Score", Defend_Score );
	SetScriptData( "Limo_Count", Limo_Count );
	SetScriptData( "Protection_Round", Protection_Round );
	SetScriptData( "RoundStarted", 0 );
	SetScriptData( "ModeLoaded", 1 );
	
	Mode_Loaded <- true;
}

function RestartProtection()
{
	Message( "The round will begin in five seconds!", Orange );
	
	/* Recreate the limos */
	DestroyLimos();
	SpawnLimos();
	
	/* Loop through players and send them to their spawns */
	PreparePlayers();
	
	NewTimer( "ReleasePlayers", 1000, 1 );
	
	/* Send the data off so the client can read it */
	SetScriptData( "Attack_Score", Attack_Score );
	SetScriptData( "Defend_Score", Defend_Score );
	SetScriptData( "Limo_Count", 4 );
	SetScriptData( "Protection_Round", Protection_Round );
}

function EndofProtectionRound()
{
	if ( Protection_Round == 1 )
	{
		local time = TicksToTarget();
		Message( "First round over, teams will now swap sides! Target time: " + time );
		Message( "30 seconds until next round...", Yellow );
		NewTimer( "SwapTeams", 25000, 1 );
		NewTimer( "RestartProtection", 30000, 1 );
		Protection_Round <- 2;
	}
	else
	{
		if ( GetTickCount() - GetScriptData( "StartTime" ) < GetScriptData( "TargetTime" ) )
		{
			Message( "The winners are the attacking team from round 2!", Orange );
			Attack_Score ++;
			SetScriptData( "Attack_Score", Attack_Score );
		}
		else
		{
			Message( "The winners are the defending team from round 1!", Orange );
			Defend_Score ++;
			SetScriptData( "Defend_Score", Defend_Score );
		}
		
		Message( "30 seconds until next round...", Yellow );
		UpdateTeamScores();
		Protection_Round <- 1;
		
		NewTimer( "SwapTeams", 25000, 1 );
		NewTimer( "RestartProtection", 30000, 1 );
	}
	SetScriptData( "RoundStarted", 0 );
}

function ReleasePlayers()
{
	local a = 0, max = GetMaxPlayers(), b = 0, max2 = GetPlayers(), pPlr;
		
	if ( Countdown > 0 )
	{
		while ( ( a < max ) && ( b < max2 ) )
		{
			pPlr = FindPlayer( a );
			if ( pPlr )
			{
				BigMessage( pPlr, "- " + Countdown + " -", 1000, 0 );
				b ++;
			}
			a ++;
		}
		Countdown --;
		NewTimer( "ReleasePlayers", 1000, 1 );
	}
	else
	{
		SetScriptData( "StartTime", GetTime() );
		SetScriptData( "RoundStarted", 1 );
	
		while ( ( a < max ) && ( b < max2 ) )
		{
			pPlr = FindPlayer( a );
			if ( pPlr )
			{
				BigMessage( pPlr, "Protection ~N~ Racket ~N~ started!", 3000, 0 );
				CallClientFunc( pPlr, "Main-C.nut", "UpdateHUD" );
				pPlr.Frozen = false;
				b ++;
			}
			a ++;
		}
		Countdown <- 5;
	}
}

function onVehicleWrecked( pVehicle )
{
	if ( pVehicle.Model == VEH_STRETCH )
	{
		/* Need to say who killed the vehicle off and decrease the limo count */
		if ( Limo_Count > 1 )
		{
			Message( "A limo has been destroyed!", Red );
			Limo_Count --;
			SetScriptData( "Limo_Count", Limo_Count );
		}
		else
		{
			if ( Protection_Round == 1 )
			{
				local StartTicks = GetScriptData( "StartTime" ), CurrentTicks = GetTime(), temp = CurrentTicks - StartTicks;
				
				SetScriptData( "TargetTime", temp );
				SetScriptData( "Limo_Count", 0 );
			}
			ShowStats();
			NewTimer( "EndofProtectionRound", 2500, 1 );
			Limo_Count <- 4;
		}
	}
}

function ShowStats()
{
	local a = 0, max = GetMaxPlayers(), b = 0, max2 = GetPlayers(), pPlr, p, name, score;
	
	/* Loop through the players to get the top three from last round */
	TempArray <- array( GetMaxPlayers() );
	
	for ( local i = 0; i < max; i++ )
	{
		p = FindPlayer( i );

		if ( p ) 
		{
			name = p.Name;
			score = p.Score.tointeger();
			TempArray[ i ] = PlrScore( name, score );
		}
		else TempArray[ i ] = PlrScore();
	}
	
	TempArray.sort( compare );
	
	if ( TempArray[ 0 ].Name )
	{
		SetScriptData( "FirstName", TempArray[ 0 ].Name );
		SetScriptData( "FirstScore", TempArray[ 0 ].Score );
	}
	if ( TempArray[ 1 ].Name )
	{
		SetScriptData( "SecondName", TempArray[ 1 ].Name );
		SetScriptData( "SecondScore", TempArray[ 1 ].Score );
	}
	if ( TempArray[ 2 ].Name )
	{
		SetScriptData( "ThirdName", TempArray[ 2 ].Name );
		SetScriptData( "ThirdScore", TempArray[ 2 ].Score );
	}
	
	/* Loop through the players to update the stats window */	
	while ( ( a < max ) && ( b < max2 ) )
	{
		pPlr = FindPlayer( a );
		if ( pPlr )
		{
			CallClientFunc( pPlr, "Main-C.nut", "StatsUpdate" );
			b ++;
		}
		a ++;
	}
}

function SwapTeams()
{
	local a = 0, max = GetMaxPlayers(), b = 0, max2 = GetPlayers(), pPlr;
	
	while ( ( a < max ) && ( b < max2 ) )
	{
		pPlr = FindPlayer( a );
		if ( pPlr )
		{
			if ( pPlr.Spawned )
			{
				if ( Info[ a ].Team == 1 ) 
				{
					Info[ a ].Team = 0;
					pPlr.Pos = Attack_Spawn;
					pPlr.Team = 1;
					pPlr.Colour = 0;
				}
				else
				{
					Info[ a ].Team = 1;
					pPlr.Pos = Defend_Spawn;
					pPlr.Team = 2;
					pPlr.Colour = 1;
				}
				BalanceTeams( pPlr );
			}
			CallClientFunc( pPlr, "Main-C.nut", "StatsUpdate" );
			CallClientFunc( pPlr, "Main-C.nut", "UpdateHUD" );
			
			b ++;
		}
		a ++;
	}
}

function BalanceTeams( pPlayer )
{
	if ( ( Attack_Count - Defend_Count ) > 1 )
	{
		/* Send them to the defending team */
		Attack_Count --;
		Defend_Count ++;
		
		Info[ pPlayer.ID ].Team = 1;
		pPlayer.Pos = Defend_Spawn;
		pPlayer.Team = 2;
		pPlayer.Colour = 1;
		
		Message( "*** " + pPlayer + " has been sent to the defending team for team balancing.", Blue );
	}
	else if ( ( Defend_Count - Attack_Count ) > 1 )
	{
		/* Send them to the attacking team */
		Attack_Count ++;
		Defend_Count --;
		
		Info[ pPlayer.ID ].Team = 0;
		pPlayer.Pos = Attack_Spawn;
		pPlayer.Team = 1;
		pPlayer.Colour = 0;
		
		Message( "*** " + pPlayer + " has been sent to the attacking team for team balancing.", Blue );
	}
}

function TicksToTime()
{
	local StartTicks = GetScriptData( "StartTime" ), CurrentTicks = GetServerTime(), temp = CurrentTicks - StartTicks, mins = temp / 60;
	
	if ( mins > 0 ) 
	{
		local remove = mins * 60;
		temp = temp - remove;
		
	}
	if ( mins < 10 ) mins = "0" + mins;
	if ( temp < 10 ) temp = "0" + temp;
	
	return mins + ":" + temp;
}

function TicksToTarget()
{
	local StartTicks = GetScriptData( "TargetTime" ), secs = StartTicks, mins = secs / 60;
	
	if ( mins > 0 ) 
	{
		local remove = mins * 60;
		secs = secs - remove;
		
	}
	if ( mins < 10 ) mins = "0" + mins;
	if ( secs < 10 ) secs = "0" + secs;
	
	return mins + ":" + secs;
}

function DestroyLimos()
{
	local a = 0, max = 4, pVehicle;
	
	while ( a < max )
	{
		pVehicle = FindVehicle( a );
		if ( pVehicle ) pVehicle.Remove();
		
		a ++;
	}	
}

function SpawnLimos()
{
	local a = 0, max = 4, pVehicle;
	
	while ( a < max )
	{
		pVehicle = CreateVehicle( VEH_STRETCH, LimoSpawns[ a ], LimoAngles[ a ] );
		pVehicle.Locked = true;
		pVehicle.IdleRespawnTime = 3600;
		pVehicle.OneTime = true;
		
		a ++;
	}
}

function PreparePlayers()
{
	local a = 0, max = GetMaxPlayers(), b = 0, max2 = GetPlayers(), pPlr;
	
	while ( ( a < max ) && ( b < max2 ) )
	{
		pPlr = FindPlayer( a );
		if ( pPlr )
		{
			if ( pPlr.Spawned )
			{
				if ( Info[ a ].Team == 1 ) pPlr.Pos = Defend_Spawn;
				else pPlr.Pos = Attack_Spawn;
				pPlr.Health = 100;
				pPlr.Armour = 100;
				
				pPlr.Frozen = true;
				BalanceTeams( pPlr );
			}
			
			b ++;
		}
		a ++;
	}
}

function UpdateTeamScores()
{
	local a = 0, max = GetMaxPlayers(), b = 0, max2 = GetPlayers(), pPlr;
	
	while ( ( a < max ) && ( b < max2 ) )
	{
		pPlr = FindPlayer( a );
		if ( pPlr )
		{
			CallClientFunc( pPlr, "Main-C.nut", "ScoreUpdate" );
			b ++;
		}
		a ++;
	}	
}